==> moengagesdk-3.5.01-sources.jar: com/moengage/core/remoteconfig/RemoteConfigDefault.java <==
package com.moengage.core.remoteconfig;

import com.moe.pushlibrary.utils.MoEHelperConstants;
import com.moengage.core.MoEConstants;
import java.util.HashSet;
import java.util.Set;

/**
 * @author Umang Chamaria
 */
public class RemoteConfigDefault {

  public static boolean LOG_ENTRY_STATUS = false;

  public static String LOG_ENTRY_TOKEN = null;

  public static long PUSH_AMP_SYNC_INTERVAL = 10800000;

  public static boolean ACCOUNT_STATUS = true;

  public static boolean IN_APP_STATUS = true;

  public static boolean GEO_FENCE_STATUS = true;

  public static boolean PUSH_AMP_STATUS = true;

  public static int EVENT_BATCH_COUNT = 30;

  public static long DATA_SYNC_RETRY_INTERVAL = 1800000L;

  public static boolean PERIODIC_FLUSH_STATE = true;

  public static long PERIODIC_FLUSH_TIME = 60;

  public static long PUSH_AMP_CAMPAIGN_EXPIRY_TIME = 2419200000L;

  public static boolean REAL_TIME_TRIGGER_STATUS = true;

  public static long REAL_TIME_TRIGGER_SYNC_INTERVAL = 10800000L;
  
  public static long USER_ATTRIBUTE_CACHING_TIME = 1800000;

  public static long DEFAULT_SESSION_INACTIVE_TIME = 1800000L;
  
  public static Set<String> DEFAULT_FLUSH_EVENTS = new HashSet<>();
  
  public static Set<String> DEFAULT_GDPR_WHITELIST_EVENTS = new HashSet<>();

  public static boolean SESSION_TRACKING_STATUS = true;

  static {
    DEFAULT_FLUSH_EVENTS.add(MoEHelperConstants.NOTIFICATION_RECEIVED_MOE);
    DEFAULT_FLUSH_EVENTS.add(MoEHelperConstants.EVENT_NOTIFICATION_CLEARED);

    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.NOTIFICATION_RECEIVED_MOE);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_NOTIFICATION_CLICKED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_NOTIFICATION_CLEARED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_SHOWN);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_CLICKED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_AUTO_DISMISS);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_CLOSE_CLICKED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.IN_APP_CHECK_FAILURE_EVENT);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_ACTION_WEB_ACTIVITY_CLICK);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEConstants.EVENT_ACTION_COUPON_CODE_COPY);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.NOTIFICATION_OFFLINE_MOE);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.DT_CAMPAIGN_SCHEDULED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEConstants.EVENT_ACTION_ACTIVITY_START);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.APP_RATED_EVENT);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.TOKEN_EVENT);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEConstants.MOE_APP_EXIT_EVENT);
  }
  public static String BLOCKED_UNIQUE_ID_REGEX = null;

  public static boolean MI_PUSH_APP_STATUS = false;
}

==> moengagesdk-3.7.02-sources.jar: com/moengage/core/remoteconfig/RemoteConfigDefault.java <==
package com.moengage.core.remoteconfig;

import com.moe.pushlibrary.utils.MoEHelperConstants;
import com.moengage.core.MoEConstants;
import java.util.HashSet;
import java.util.Set;

/**
 * @author Umang Chamaria
 */
public class RemoteConfigDefault {

  public static boolean LOG_ENTRY_STATUS = false;

  public static String LOG_ENTRY_TOKEN = null;

  public static long PUSH_AMP_SYNC_INTERVAL = 10800000;

  public static boolean ACCOUNT_STATUS = true;

  public static boolean IN_APP_STATUS = true;

  public static boolean GEO_FENCE_STATUS = true;

  public static boolean PUSH_AMP_STATUS = false;

  public static int EVENT_BATCH_COUNT = 30;

  public static long DATA_SYNC_RETRY_INTERVAL = 1800000L;

  public static boolean PERIODIC_FLUSH_STATE = true;

  public static long PERIODIC_FLUSH_TIME = 60;

  public static long PUSH_AMP_CAMPAIGN_EXPIRY_TIME = 2419200000L;

  public static boolean REAL_TIME_TRIGGER_STATUS = false;

  public static long REAL_TIME_TRIGGER_SYNC_INTERVAL = 10800000L;
  
  public static long USER_ATTRIBUTE_CACHING_TIME = 1800000;

  public static long DEFAULT_SESSION_INACTIVE_TIME = 1800000L;
  
  public static Set<String> DEFAULT_FLUSH_EVENTS = new HashSet<>();
  
  public static Set<String> DEFAULT_GDPR_WHITELIST_EVENTS = new HashSet<>();

  static {
    DEFAULT_FLUSH_EVENTS.add(MoEHelperConstants.NOTIFICATION_RECEIVED_MOE);
    DEFAULT_FLUSH_EVENTS.add(MoEHelperConstants.EVENT_NOTIFICATION_CLEARED);

    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.NOTIFICATION_RECEIVED_MOE);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_NOTIFICATION_CLICKED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_NOTIFICATION_CLEARED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_SHOWN);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_CLICKED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_AUTO_DISMISS);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_IN_APP_CLOSE_CLICKED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.IN_APP_CHECK_FAILURE_EVENT);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.EVENT_ACTION_WEB_ACTIVITY_CLICK);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEConstants.EVENT_ACTION_COUPON_CODE_COPY);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.NOTIFICATION_OFFLINE_MOE);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.DT_CAMPAIGN_SCHEDULED);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEConstants.EVENT_ACTION_ACTIVITY_START);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.APP_RATED_EVENT);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEHelperConstants.TOKEN_EVENT);
    DEFAULT_GDPR_WHITELIST_EVENTS.add(MoEConstants.MOE_APP_EXIT_EVENT);
  }
  public static String BLOCKED_UNIQUE_ID_REGEX = null;

  public static boolean MI_PUSH_APP_STATUS = false;
}
